import {Button, Card, Form, Input, message} from 'antd';
import React from 'react';
import {PageHeaderWrapper} from '@ant-design/pro-layout';
import service from './service';

interface PasswordChange{
  newPassword: string;
  oldPassword: string;
}

const layout = {
  labelCol: { span: 4 },
  wrapperCol: { span: 18 },
};
const tailLayout = {
  wrapperCol: { offset: 4, span: 18 },
};



/**
 * 更新节点
 * @param fields
 */
const handleUpdate = async (fields: PasswordChange) => {
  const hide = message.loading('正在发送');
  try {
    const data = await service.updatePassword(fields);
    if (data.success) {
      hide();
      message.success('修改成功');
    } else {
      message.error('修改失败！');
    }
  }catch (e) {
    console.log(e);
  }
};

const TableList: React.FC<{}> = () => {
  const onFinish = (values: any) => {
    handleUpdate(values);
  };

  // const onFinishFailed = errorInfo => {
  //   console.log('Failed:', errorInfo);
  // };

  return (
    <PageHeaderWrapper title={false}>
      <Card title="重置密码"  style={{ width: '100%' }}>
        <Form
          {...layout}
          name="basic"
          initialValues={{ remember: true }}
          onFinish={onFinish}
          // onFinishFailed={onFinishFailed}
        >
          <Form.Item
            label="旧密码"
            name="oldPassword"
            rules={[{ required: true, message: '请输入旧密码!' }]}
          >
            <Input.Password />
          </Form.Item>

          <Form.Item
            label="新密码"
            name="newPassword"
            rules={[{ required: true, message: '请输入旧密码' }]}
          >
            <Input.Password />
          </Form.Item>

          <Form.Item {...tailLayout}>
            <Button type="primary" htmlType="submit">
              提交
            </Button>
          </Form.Item>
        </Form>
      </Card>

    </PageHeaderWrapper>
  );
};

export default TableList;
